Changelog
=========

0.8.1 - 2014-09-19
----------------

Fixed
~~~~~

- Boo boo during the release because of missing HISTORY.rst file


0.8 - 2014-09-19
----------------

Added
~~~~~

-  requests-futures support, making everything a whole heap faster
-  Added documentation for the --latest feature that's been there from
   the beginning
-  Added --notify-post-commit argument to output a post-commit hook to
   automatically notify
-  Improved documentation for --notify feature

Fixed
~~~~~

-  Fixed a bunch of PyLint errors and suggestions

0.7.2 - 2014-08-16
------------------

Added
~~~~~

-  Nothing

Deprecated
~~~~~~~~~~

-  Nothing.

Removed
~~~~~~~

-  Nothing.

Fixed
~~~~~

-  Use rst for PyPI long description field

0.7.1 - 2014-08-16
------------------

Added
~~~~~

-  Updated setup.py to include README in long\_description for PyPI
-  Added Notifications section to README with piprot.io details
-  Added new tests for recursive requirements files

Deprecated
~~~~~~~~~~

-  Nothing.

Removed
~~~~~~~

-  Nothing.

Fixed
~~~~~

-  Nothing.

0.7.0 - 2014-08-11
------------------

Added
~~~~~

-  This CHANGELOG file, hopefully encouraging me to tell the world more
   about changes to this project
-  Support for piprot.io notifications

Deprecated
~~~~~~~~~~

-  Nothing.

Removed
~~~~~~~

-  Nothing.

Fixed
~~~~~

-  Nothing.
